Module protocol_json

Module protocol_json 

Helpers for converting typed Rust query args into engine wire JSON. Convert typed Rust query arguments into the JSON shape consumed by the engine.

Functions

find_many_args_to_protocol_json
Convert FindManyArgs into the same JSON payload shape used by thin clients.
find_many_args_to_protocol_object
Convert FindManyArgs into an object map matching the engine wire format.
where_expr_to_protocol_json
Convert a single Rust filter expression into the engine wire-format "where" object.