Module serialization

Module serialization 

(De)serialization utilities bridging Rust ↔︎ Python types.

Functions

from_dict_pyo3
Convert a Python dictionary to a Rust type that implements DeserializeOwned.
from_pyobject_pyo3
Convert a Python object to a Rust type that implements DeserializeOwned.
hashmap_from_pyobject_pyo3
Convert a Python mapping to a HashMap using typed PyO3 objects when possible.
hashmap_to_pydict_pyo3
Convert a HashMap to a Python dict using typed PyO3 keys and values.
indexmap_from_pyobject_pyo3
Convert a Python mapping to an IndexMap using typed PyO3 objects when possible.
indexmap_to_pydict_pyo3
Convert an IndexMap to a Python dict using typed PyO3 keys and values.
to_dict_pyo3
Convert a Rust type that implements Serialize to a Python dictionary.
to_pyobject_pyo3
Convert a Rust type that implements Serialize to a Python object.