from_pyobject_pyo3

Function from_pyobject_pyo3 

pub fn from_pyobject_pyo3<T>(
    py: Python<'_>,
    value: &Bound<'_, PyAny>,
) -> Result<T, PyErr>
Convert a Python object to a Rust type that implements DeserializeOwned.

Errors

Returns an error if:

  • The Python object cannot be serialized to JSON.
  • The JSON string cannot be deserialized to type T.
  • The Python json module fails to import or execute.