Module select

Module select 

SELECT query AST and builder. SELECT query AST and builder.

Structs

JoinClause
A JOIN clause attached to a SELECT query.
OrderBy
ORDER BY clause item.
Select
SELECT query AST node.
SelectBuilder
Builder for SELECT queries.
SelectCapacity
Reserved capacities for the Vecs maintained by a SelectBuilder.

Enums

JoinType
Type of JOIN operation.
OrderByItem
One ORDER BY item in the original user-specified sequence.
OrderDir
Sort direction for ORDER BY clauses.
SelectItem
A select list item that can be either a simple column or a computed expression.