pub struct IncludeRelation {
pub where_: Option<Expr>,
}Expand description
Arguments for eagerly loading a single relation in a query.
include: { posts: { where: { published: true } } }Fields
where_: Option<Expr>Optional filter to apply to the included child records.
Implementations
Sourceimpl IncludeRelation
impl IncludeRelation
Sourcepub fn with_filter(filter: Expr) -> Self
pub fn with_filter(filter: Expr) -> Self
Create an include with a child filter.