Helpers for converting typed Rust query args into engine wire JSON. Convert typed Rust query arguments into the JSON shape consumed by the engine.
Functions
- find_
many_ args_ to_ protocol_ json - Convert
FindManyArgsinto the same JSON payload shape used by thin clients. - find_
many_ args_ to_ protocol_ object - Convert
FindManyArgsinto an object map matching the engine wire format. - where_
expr_ to_ protocol_ json - Convert a single Rust filter expression into the engine wire-format
"where"object.