pub fn value_to_pyobject(py: Python<'_>, val: &Value) -> PyResult<Py<PyAny>>Expand description
Helper function to convert a serde_json::Value to a Python object.
This is a common conversion pattern used when converting Params to Python dicts.
Errors
Returns a PyErr if the value type is unsupported or conversion fails.