(De)serialization utilities bridging Rust ↔︎ Python types.
Functions
- from_
dict_ pyo3 - Convert a Python dictionary to a Rust type that implements
DeserializeOwned. - from_
pyobject_ pyo3 - Convert a Python object to a Rust type that implements
DeserializeOwned. - hashmap_
from_ pyobject_ pyo3 - Convert a Python mapping to a
HashMapusing typed PyO3 objects when possible. - hashmap_
to_ pydict_ pyo3 - Convert a
HashMapto a Python dict using typed PyO3 keys and values. - indexmap_
from_ pyobject_ pyo3 - Convert a Python mapping to an
IndexMapusing typed PyO3 objects when possible. - indexmap_
to_ pydict_ pyo3 - Convert an
IndexMapto a Python dict using typed PyO3 keys and values. - to_
dict_ pyo3 - Convert a Rust type that implements
Serializeto a Python dictionary. - to_
pyobject_ pyo3 - Convert a Rust type that implements
Serializeto a Python object.